"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunsClient = void 0;
/**
 * RunsClient is used to list and manage runs
 */
class RunsClient {
    constructor(client) {
        this.api = client.api;
        this.tenantId = client.tenantId;
    }
    // TODO expose streaming methods?
    get(run) {
        return __awaiter(this, void 0, void 0, function* () {
            const runId = typeof run === 'string' ? run : yield run.getWorkflowRunId();
            const { data } = yield this.api.workflowRunGet(this.tenantId, runId);
            return data;
        });
    }
    getDetails(run) {
        return __awaiter(this, void 0, void 0, function* () {
            const runId = typeof run === 'string' ? run : yield run.getWorkflowRunId();
            const { data } = yield this.api.workflowRunGetShape(this.tenantId, runId);
            return data;
        });
    }
    list(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO workflow id on opts is a uuid
            const { data } = yield this.api.workflowRunList(this.tenantId, opts);
            return data;
        });
    }
    replay(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO is v1 check
            // TODO   workflowIds?: string[]; on opts.filters
            const { data } = yield this.api.v1TaskReplay(this.tenantId, opts);
            return data;
        });
    }
    cancel(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO is v1 check
            // TODO   workflowIds?: string[]; on opts.filters
            const { data } = yield this.api.v1TaskCancel(this.tenantId, opts);
            return data;
        });
    }
}
exports.RunsClient = RunsClient;
